#

##

###

###

    	show variable

    	inspect with pexpect = infinite loop

    		example 1
    			frame = inspect.currentframe ().f_back
    			print ('frame2:', inspect.getframeinfo (inspect.currentframe ()))
    			print ('frame:', frame)
    			print ('frame2:', inspect.getframeinfo (frame))
    			filename = inspect.getframeinfo (frame).filename
    			lineno = inspect.getframeinfo (frame).lineno

    		example 2
    			print (inspect.stack())